@@ -12,9 +12,9 @@ from specfile.tags import Comment, Comments, Tag, Tags
 def test_find():
     tags = Tags(
         [
-            Tag("Name", "test", "test", ": ", Comments()),
-            Tag("Version", "0.1", "0.1", ": ", Comments()),
-            Tag("Release", "1%{?dist}", "1.fc35", ": ", Comments()),
+            Tag("Name", "test", ": ", Comments()),
+            Tag("Version", "0.1", ": ", Comments()),
+            Tag("Release", "1%{?dist}", ": ", Comments()),
         ]
     )
     assert tags.find("version") == 1
@@ -44,47 +44,28 @@ def test_parse():
                 "Requires:          make",
                 "Requires(post):    bash",
                 "",
+                "Provides:          testX = %{version}-%{release}",
+                "Provides:          bundled(superlib) = 2.42.0",
+                "",
                 "%{?fedora:Suggests:          diffutils}",
             ],
-        ),
-        Section(
-            "package",
-            data=[
-                "",
-                "",
-                "",
-                "# this is a test package",
-                "# not to be used in production",
-                "Name:    test",
-                "Version: 1.0",
-                "  # this is a valid comment",
-                "Release: 1.fc35",
-                "",
-                "",
-                "",
-                "",
-                "",
-                "Requires:          make",
-                "Requires(post):    bash",
-                "",
-                "Suggests:          diffutils",
-            ],
-        ),
+        )
     )
     assert tags[0].name == "Name"
     assert tags[0].comments[0].text == "this is a test package"
     assert tags[0].comments[1].text == "not to be used in production"
     assert tags[1].name == "Version"
     assert tags[1].value == "%{ver_major}.%{ver_minor}"
-    assert tags[1].valid
-    assert tags[1].expanded_value == "1.0"
     assert not tags[1].comments
     assert tags.release.comments[0].prefix == "  # "
     assert tags.epoch.name == "Epoch"
-    assert not tags.epoch.valid
     assert tags.requires.value == "make"
     assert "requires(post)" in tags
-    assert tags[-2].name == "Requires(post)"
+    assert tags[-4].name == "Requires(post)"
+    assert tags[-3].name == "Provides"
+    assert tags[-3].value == "testX = %{version}-%{release}"
+    assert tags[-2].name == "Provides"
+    assert tags[-2].value == "bundled(superlib) = 2.42.0"
     assert tags[-1].name == "Suggests"
     assert tags.suggests.value == "diffutils"
 
@@ -95,7 +76,6 @@ def test_get_raw_section_data():
             Tag(
                 "Name",
                 "test",
-                "test",
                 ":    ",
                 Comments(
                     [
@@ -105,23 +85,19 @@ def test_get_raw_section_data():
                     ["%global ver_major 1", "%global ver_minor 0", ""],
                 ),
             ),
-            Tag("Version", "%{ver_major}.%{ver_minor}", "1.0", ": ", Comments()),
+            Tag("Version", "%{ver_major}.%{ver_minor}", ": ", Comments()),
             Tag(
                 "Release",
                 "1%{?dist}",
-                "1.fc35",
                 ": ",
                 Comments([Comment("this is a valid comment", "  # ")]),
             ),
-            Tag("Epoch", "1", "", ":   ", Comments([], ["", "%if 0"])),
-            Tag(
-                "Requires", "make", "make", ":          ", Comments([], ["%endif", ""])
-            ),
-            Tag("Requires(post)", "bash", "bash", ":    ", Comments()),
+            Tag("Epoch", "1", ":   ", Comments([], ["", "%if 0"])),
+            Tag("Requires", "make", ":          ", Comments([], ["%endif", ""])),
+            Tag("Requires(post)", "bash", ":    ", Comments()),
             Tag(
                 "Suggests",
                 "diffutils",
-                "diffutils",
                 ":          ",
                 Comments([], [""]),
                 "%{?fedora:",
@@ -155,7 +131,7 @@ def test_get_raw_section_data():
 def test_copy_tags():
     tags = Tags(
         [
-            Tag("Name", "test", "test", ": ", Comments()),
+            Tag("Name", "test", ": ", Comments()),
         ]
     )
     shallow_copy = copy.copy(tags)
